From: Robert Qian <rbq@google.com
Date: Wed, 31 May 2023 15:45:02 -0400
Last-Update: 2023-05-31
Subject: [PATCH] disable dns tests since they fail on builders with limited networking

nsm-test.el and process-tests.el contain tests that may fail on builders where the 
network may be restricted, which causes build failures. This patch disables those tests.

---
Index: emacs-28.2+1/test/lisp/net/nsm-tests.el
===================================================================
--- emacs-28.2+1.orig/test/lisp/net/nsm-tests.el
+++ emacs-28.2+1/test/lisp/net/nsm-tests.el
@@ -29,6 +29,7 @@
 
 (ert-deftest nsm-check-local-subnet-ipv4 ()
   "Check that nsm can be avoided for local subnets."
+  :tags '(:unstable)  ; This test fails on builders with limited network access
   (let ((local-ip '[172 26 128 160 0])
         (mask '[255 255 255 0 0])
 
Index: emacs-28.2+1/test/src/process-tests.el
===================================================================
--- emacs-28.2+1.orig/test/src/process-tests.el
+++ emacs-28.2+1/test/src/process-tests.el
@@ -377,6 +377,7 @@ See Bug#30460."
 
 (ert-deftest lookup-unicode-domains ()
   "Unicode domains should fail."
+  :tags '(:unstable)  ; This test fails on builders with limited network access
   (skip-unless internet-is-working)
   (with-timeout (60 (ert-fail "Test timed out"))
   (should-error (network-lookup-address-info "faß.de"))
@@ -384,12 +385,14 @@ See Bug#30460."
 
 (ert-deftest unibyte-domain-name ()
   "Unibyte domain names should work."
+  :tags '(:unstable)  ; This test fails on builders with limited network access
   (skip-unless internet-is-working)
   (with-timeout (60 (ert-fail "Test timed out"))
   (should (network-lookup-address-info (string-to-unibyte "google.com")))))
 
 (ert-deftest lookup-google ()
   "Check that we can look up google IP addresses."
+  :tags '(:unstable)  ; This test fails on builders with limited network access
   (skip-unless internet-is-working)
   (with-timeout (60 (ert-fail "Test timed out"))
   (let ((addresses-both (network-lookup-address-info "google.com"))
@@ -920,6 +923,7 @@ Return nil if FILENAME doesn't exist."
 
 (ert-deftest process-async-https-with-delay ()
   "Bug#49449: asynchronous TLS connection with delayed completion."
+  :tags '(:unstable)  ; This test fails on builders with limited network access
   (skip-unless (and internet-is-working (gnutls-available-p)))
   (let* ((status nil)
          (buf (url-http
